
// -*- C++ -*-

// (c) COPYRIGHT URI/MIT 1999
// Please read the full copyright statement in the file COPYRIGHT.
//
// Authors:
//      jhrg,jimg       James Gallagher (jgallagher@gso.uri.edu)

#include "config_jg.h"

#ifdef __GNUG__
#pragma implementation
#endif

#include "Error.h"
#include "JGUInt16.h"
#include "jgofs.h"

UInt16 *
NewUInt16(const string &n)
{
    return new JGUInt16(n);
}

JGUInt16::JGUInt16(const string &n) : UInt16(n)
{
    _missing_val = USHRT_MAX;
}

BaseType *
JGUInt16::ptr_duplicate()
{
    return new JGUInt16(*this);
}

bool
JGUInt16::read(const string &dataset)
{
  for (int j = 0; j < nVars; ++j) {
    if (name() == varName[j]) {
      char *errptr;
      dods_uint16 df = strtol(varValue[j], &errptr, 0);

      if ( errptr != (char *)&(varValue[j]) )
	val2buf(&df);
      else 
	val2buf(&_missing_val);	      

      set_read_p(true);
      return true;
    }
  }

  // If we're here, the variable was not found. throw and error.
  string s = (string)"Variable " + name() 
    + " wasn't located in JGOFS object " + dataset + ".";
  throw Error(unknown_error, s);
}

dods_uint16
JGUInt16::get_missing_value() const
{
    return _missing_val;
}

void
JGUInt16::set_missing_value(const dods_uint16 &v)
{
    _missing_val = v;
}

void
JGUInt16::set_missing_value(const  string &attribute)
{
    _missing_val = atoi(attribute.c_str());
}

// $Log: JGUInt16.cc,v $
// Revision 1.6  2003/01/16 07:57:34  jimg
// Merged changes from release-3-2-6.
// Removed a number of files used for the client library ans sample clients.
//
// Revision 1.4.4.3  2003/01/14 05:36:46  jimg
// I added a set_missing_value(const string &) method. This lets the code
// in jgdds.cc that builds a DDS (which may contain types other than string
// if that has been configured in the dataset's DAS) set up the missing
// values using information from the DAS without doing string to value
// conversions for each numeric type in a big switch statement.
//
// Revision 1.5  2001/08/27 17:41:03  jimg
// Merged with release-3-2-2
//
// Revision 1.4.4.2  2001/08/21 15:14:12  dan
// Updated names of the set/get accessor methods for modifying the missing_value
// member field, to make the naming convention consistent with the current
// DAP usage.
//
// Revision 1.4.4.1  2001/05/31 19:14:23  dan
// Modified return value from read method, now returns true.
//
// Revision 1.4  2000/10/10 23:36:14  jimg
// Added exception processing code.
// Added throws to the read methods.
// Changed the definition of read to match the dap library.
// Moved CVS Log entries to the end of files.
//
// Revision 1.3  1999/11/05 01:17:24  jimg
// Result of merge with release-3-1-0
//
// Revision 1.2.6.2  1999/10/30 19:43:56  dan
// Added explicit (char *) cast in error-checking within read().
//
// Revision 1.2.6.1  1999/10/24 18:30:32  dan
// Modified to support type conversion from JGOFS
// string variables to dods_uint16.
//
// Revision 1.2  1999/05/05 22:57:18  jimg
// Merged Brent's String --> string changes with Dan's changes
//
// Revision 1.1  1999/03/27 01:00:34  jimg
// Added
//
