/*
  This file contains common extern declarations used by the DODS-JGOFS code.
  jhrg 3/12/95
*/

#ifndef _jgofs_h
#define _jgofs_h 1

/* 
   These constants must match the definitions in ljgofs/ljdb.c
*/

#define NVALS 250
#define TOKEN 40
#define ATTRLEN 256
#define VALSIZE 80
/* Changed MAX_BUF from 1025 to 2048 to accomodate NSCAT data. jhrg 11/8/96 */
#define MAX_BUF 2048

#define HTSIZE 4096
#define NUMNAMES NVALS
#define ATTRSIZE 1024
#define COMMENTSIZE 2048
#define MAX_UNITS 5

/* These are defined in jgdds.cc */
extern char varName[NVALS][TOKEN];
extern char varValue[NVALS][VALSIZE];
extern int varLevel[NVALS];
extern int nVars, unit;
extern int varSize;

/* 
   These external symbols force the linker to extract all of the object
   modules that are used to specialize the classes in the dods client-server
   toolkit. This is necessary since the linker otherwise does not think it is
   necessary to include all of the object modules.
*/

#ifdef __cplusplus
extern "C" {
#endif

    /* Prototypes for the original API */
    int jdbopen_(int *unit, char*, char(*)[TOKEN], int*, int*);
    int jdblevel_(int *unit, int*);
    int jdbattributes_(int *unit, int*, char *);
    int jdbreada_(int *unit, char(*)[VALSIZE], int*);
    int jdbclose_(int *unit);


    /* Our own (DODS) versions of these functions. */
    int ljdbopen_(int *unit, const char *objpath, const char *metpath, 
		  const char *obj, char *names, const int *namesize, int *num);
    int ljdbread_(const int *unit, float values[]);
    int ljdbreada_(const int *unit, char *values, const int *valuesize);
    int ljdbcomments_(const int *unit, char *outcom);
    int ljdbattributes_(const int *unit, int *id, char *outcom);
    void ljdbclose_(const int *unit);
    int ljdblevel_(const int *unit, int *varnum);
    int ljdberror_(const int *unit, char *jdbError);

    int test_jg_path(const char *pathname);
    int ldctsearch(const char *object_path, const char *method_path, 
		   const char *obj, char *method, char *params, int localflag);

#ifdef __cplusplus
}
#endif

/*
 * $Log: jgofs.h,v $
 * Revision 1.3  2003/01/16 20:22:02  jimg
 * Fixed the CVS Log so that the comments aren't malformed.
 *
 * Revision 1.2  2003/01/16 07:57:35  jimg
 * Merged changes from release-3-2-6.
 * Removed a number of files used for the client library ans sample clients.
 *
 * Revision 1.1.2.1  2003/01/16 06:54:18  jimg
 * Moved from the parent directory.
 *
 * Revision 1.9.4.1  2001/08/21 15:36:28  dan
 * Modified argument lists to reflect parameters passed to support
 * relative pathname searching for local object dictionaries.
 *
 * Revision 1.9  2000/10/10 23:36:14  jimg
 * Added exception processing code.
 * Added throws to the read methods.
 * Changed the definition of read to match the dap library.
 * Moved CVS Log entries to the end of files.
 *
 * Revision 1.8  1998/02/05 20:14:40  jimg
 * DODS now compiles with gcc 2.8.x
 *
 * Revision 1.7  1997/12/31 19:13:33  jimg
 * Fixed up the comments.
 *
 * Revision 1.6  1996/12/18 17:42:36  jimg
 * Comments added. Not much of a change, really.
 *
 * Revision 1.5  1996/09/17 00:04:15  jimg
 * Misc changes associated with merging branch code to the trunk.
 *
 * Revision 1.4.2.1  1996/04/02 19:43:10  jimg
 * Fixed errors in comment header.
 * Removed code that was being excluded with #ifdef NEVER ... #endif.
 *
 * Revision 1.4  1995/10/11  23:56:12  jimg
 * Added external symbols defined/declared in jgofs.h to lgofs/ljdb.c. Fixed
 * the C constant TOKEN so that it is `40' everywhere.
 *
 * Revision 1.3  1995/09/18  22:50:02  jimg
 * These files changed as a result of edit Dan made to the jg-dods code so that
 * the servers use exiting jgofs methods (i.e., one set of jg-dods servers can
 * be used to access N methods, without the linking hack previously used).
 *
 * Revision 1.2  1995/03/14  02:19:23  jimg
 * Removed files.
 */

#endif /* _jgofs_h */
